"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const paths_1 = require("../config/paths");
const appendContentToFile_1 = (0, tslib_1.__importDefault)(require("./fns/appendContentToFile"));
/**
 * 获取首页
 *
 * @param options 配置项
 */
function getHomepage(options) {
    if (options.packageName.startsWith('@')) {
        const matches = options.packageName.match(/@([^/])\/(.+)/);
        if (matches) {
            const [, scopeName, packageName] = matches;
            return `https://${scopeName}.github.io/${packageName}`;
        }
    }
    return undefined;
}
/**
 * 生成docz文件
 *
 * @param projectPath 项目路径
 * @param options 配置
 */
async function genDoczFiles(projectPath, options) {
    // 拷贝docz文件
    await (0, fs_extra_1.copy)(paths_1.DOCZ_TEMPLATE_PATH, projectPath);
    // 更新docz文档页面的标题
    const content = await (0, fs_extra_1.readFile)((0, path_1.resolve)(projectPath, './doczrc.js'), 'utf-8');
    await (0, fs_extra_1.writeFile)((0, path_1.resolve)(projectPath, './doczrc.js'), content.replace("title: 'rctt',", `title: '${options.projectName}',`));
    // 添加文档命令
    const packageInfo = await (0, fs_extra_1.readJSON)((0, path_1.resolve)(projectPath, './package.json'));
    packageInfo.scripts['doc:dev'] = 'docz dev';
    packageInfo.scripts['doc:build'] = 'docz build';
    if (options.doczGithubPages) {
        packageInfo.scripts['doc:publish'] = 'docz build && gh-pages -d .docz/dist';
        packageInfo.homepage = getHomepage(options);
    }
    await (0, fs_extra_1.outputJSON)((0, path_1.resolve)(projectPath, './package.json'), packageInfo, {
        spaces: 2,
    });
    // 添加doc指令说明
    await (0, appendContentToFile_1.default)((0, path_1.resolve)(projectPath, 'README.md'), '\n', (0, fs_extra_1.createReadStream)(paths_1.DOC_README_PATH));
}
exports.default = genDoczFiles;
//# sourceMappingURL=genDoczFiles.js.map