"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOptions = exports.getReactOptionsWithConfirm = exports.getOptionsWithConfirm = void 0;
const enquirer_1 = require("enquirer");
/**
 * 以交互方式获取配置
 *
 * @param options 配置项
 */
async function getOptionsWithConfirm(options) {
    const confirms = [
        {
            type: 'input',
            name: 'pacakgeVersion',
            message: '项目版本号',
            initial: options.packageVersion,
        },
        {
            type: 'input',
            name: 'packageName',
            initial: options.packageName,
            message: '项目名称',
        },
        {
            type: 'input',
            name: 'packageDescription',
            message: '项目描述',
        },
        {
            type: 'input',
            name: 'author',
            message: '作者',
        },
    ];
    const response = await (0, enquirer_1.prompt)(confirms);
    return { ...options, ...response };
}
exports.getOptionsWithConfirm = getOptionsWithConfirm;
/**
 * 获取React组件开发相关的配置
 *
 * @param options 配置项
 */
async function getReactOptionsWithConfirm(options) {
    const { react } = await (0, enquirer_1.prompt)({
        type: 'confirm',
        name: 'react',
        skip: options.react,
        message: '开发React组件？',
        initial: options.react,
    });
    const { docz } = await (0, enquirer_1.prompt)({
        type: 'confirm',
        name: 'docz',
        skip: !react || !!options.docz,
        message: '使用docz编写组件文档？',
        initial: react,
    });
    const { doczGithubPages } = await (0, enquirer_1.prompt)({
        type: 'confirm',
        name: 'doczGithubPages',
        skip: () => !docz || !!options.doczGithubPages,
        message: '将docz文档发布到Github Pages上？',
        initial: docz,
    });
    return { ...options, react, docz, doczGithubPages };
}
exports.getReactOptionsWithConfirm = getReactOptionsWithConfirm;
/**
 * 获取命令行参数
 *
 * @param projectName 项目名称
 * @param packageName 模块名
 * @param program 命令行程序
 */
async function getOptions(projectName, packageName, program) {
    let options = {
        version: program.v,
        projectName,
        packageName,
        packageDescription: program.packageDescription,
        packageVersion: program.packageVersion,
        react: program.react,
        monorepo: program.monorepo,
        npmScope: program.npmScope,
    };
    if (program.i) {
        options = await getOptionsWithConfirm(options);
    }
    options = await getReactOptionsWithConfirm(options);
    return options;
}
exports.getOptions = getOptions;
//# sourceMappingURL=getOptions.js.map