"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/no-require-imports */
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const enquirer_1 = require("enquirer");
const execa_1 = (0, tslib_1.__importDefault)(require("execa"));
const ora_1 = (0, tslib_1.__importDefault)(require("ora"));
const ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
const paths_1 = require("../config/paths");
const createGitRepository_1 = (0, tslib_1.__importDefault)(require("./createGitRepository"));
const genMonorepoProject_1 = (0, tslib_1.__importDefault)(require("./genMonorepoProject"));
const genProject_1 = require("./genProject");
const getOptions_1 = require("./getOptions");
const gitCommit_1 = (0, tslib_1.__importDefault)(require("./gitCommit"));
const init_husky_1 = (0, tslib_1.__importDefault)(require("./init-husky"));
const installDeps_1 = (0, tslib_1.__importDefault)(require("./installDeps"));
const isCmdInstalled_1 = (0, tslib_1.__importDefault)(require("./isCmdInstalled"));
const validatePackageName_1 = require("./validatePackageName");
/**
 * 创建项目
 *
 * @param projectNameConfig 配置名称配置
 * @param program 命令行对象
 */
async function create(projectNameConfig, program) {
    const projectName = projectNameConfig.startsWith('@')
        ? projectNameConfig.substr(projectNameConfig.indexOf('/') + 1)
        : projectNameConfig;
    const packageName = (program.packageName || projectNameConfig);
    if (!(0, validatePackageName_1.validatePackageName)(packageName)) {
        process.exit(1);
    }
    const options = await (0, getOptions_1.getOptions)(projectName, packageName, program);
    if (packageName.startsWith('@') && !options.npmScope && options.monorepo) {
        console.error(`monorepo模式时，项目，项目名称不能以@开头。现在是：${packageName}`);
        return;
    }
    const spinner = (0, ora_1.default)().start();
    spinner.start('正在生成项目...');
    try {
        if (options.monorepo) {
            await (0, genMonorepoProject_1.default)(options);
        }
        else {
            await (0, genProject_1.genProject)(options);
        }
        spinner.succeed(`已生成项目 ${chalk_1.default.green(packageName)}`);
    }
    catch (error) {
        spinner.fail('生成项目失败');
        (0, ts_lib_scripts_utils_1.logError)(error);
        process.exit(1);
    }
    const projectPath = (0, paths_1.resolveRoot)(options.projectName);
    const gitCreated = (0, createGitRepository_1.default)(projectPath);
    await (0, installDeps_1.default)(spinner, options);
    if (gitCreated) {
        try {
            await (0, init_husky_1.default)(spinner, options.projectName);
            (0, gitCommit_1.default)(projectPath);
        }
        catch (error) {
            // 忽略git提交失败
        }
    }
    if (await (0, isCmdInstalled_1.default)('code')) {
        console.log();
        const { openWithCode } = await (0, enquirer_1.prompt)({
            type: 'confirm',
            name: 'openWithCode',
            message: '使用vscode打开项目？',
            initial: 'Y',
        });
        if (openWithCode) {
            await (0, execa_1.default)('code', [projectName]);
        }
    }
    process.exit(0);
}
exports.default = create;
//# sourceMappingURL=index.js.map