"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable @typescript-eslint/no-require-imports */
const execa_1 = (0, tslib_1.__importDefault)(require("execa"));
const ts_lib_scripts_utils_1 = require("ts-lib-scripts-utils");
const paths_1 = require("../config/paths");
const constants_1 = require("./constants");
const messages_1 = require("./messages");
/**
 * 获取开发依赖
 *
 * @param options 配置项
 */
function getDevPendencies(options) {
    return [
        ...constants_1.devDependencies,
        ...(options.react ? constants_1.devDependenciesForReact : []),
        ...(options.docz ? constants_1.devDependenciesForDocz : []),
        ...(options.doczGithubPages ? constants_1.devDependenciesForGhpages : []),
        ...(options.monorepo ? constants_1.monorepoDevDependencies : []),
    ];
}
/**
 * 执行安装依赖的命令
 *
 * @param projectName 项目名称
 * @param deps 依赖
 * @param isDev 是否是开发依赖
 * @param monorepo 是否是 monorepo 模式
 */
async function execInstallDeps(projectName, deps, isDev = false, monorepo = false) {
    const cmd = (0, ts_lib_scripts_utils_1.getInstallCmd)();
    const args = [
        cmd === 'npm' ? 'i' : 'add',
        ...deps,
        isDev ? '--dev' : '',
        cmd === 'npm' ? '--save' : '',
        cmd === 'yarn' && monorepo ? '-W' : '',
        '--ignore-scripts',
    ].filter(Boolean);
    await (0, execa_1.default)(cmd, args, {
        cwd: (0, paths_1.resolveRoot)(projectName),
    });
}
/**
 * 安装依赖
 *
 * @param spinner 进度条
 * @param options 配置
 */
async function installDeps(spinner, options) {
    const { projectName, monorepo } = options;
    const devDeps = getDevPendencies(options);
    spinner.start((0, messages_1.dependenciesMessage)(constants_1.dependencies, devDeps));
    try {
        await execInstallDeps(projectName, devDeps, true, !!monorepo);
        await execInstallDeps(projectName, constants_1.dependencies, false, !!monorepo);
        spinner.succeed('安装依赖包');
        (0, messages_1.successMessage)((0, ts_lib_scripts_utils_1.getInstallCmd)(), projectName);
    }
    catch (error) {
        (0, ts_lib_scripts_utils_1.logError)(error);
        spinner.fail(`安装依赖失败`);
        (0, messages_1.failureMessage)([
            (0, ts_lib_scripts_utils_1.getInstallDepsCmd)(constants_1.dependencies, false, !!monorepo),
            (0, ts_lib_scripts_utils_1.getInstallDepsCmd)(devDeps, true, !!monorepo),
        ]);
        process.exit(1);
    }
}
exports.default = installDeps;
//# sourceMappingURL=installDeps.js.map